# Cli-Calculaotr

A simple commandline calculator app

# Installation

## Using Pip

```bash
  $ pip install bambic
```

## Manual

```bash
  $ git clone https://github.com/choonghee-lee/cli-calculator
  $ cd cli-calculator
  $ python setup.py install
```

# Usage

```bash
$ bambic --help
```
